@@ -48,7 +48,7 @@ AbstractParameterAliasable::AbstractParameterAliasable(const AbstractParameterAl
   independentParameters_(),
   aliasListenersRegister_()
 {
-  for (size_t i=0; i<ap.independentParameters_.size(); i++)
+  for (size_t i = 0; i < ap.independentParameters_.size(); i++)
     independentParameters_.shareParameter(getSharedParameter(getParameterNameWithoutNamespace(ap.independentParameters_[i].getName())));
   
   // Actualize the register with adequate pointers:
@@ -178,8 +178,8 @@ void AbstractParameterAliasable::aliasParameters(map<string, string>& unparsedPa
   size_t unp_s = unparsedParams.size();
   while (unp_s != 0)
   {
-    map<string, string>::iterator it;
-    for (it = unparsedParams.begin(); it != unparsedParams.end(); it++)
+    auto it = unparsedParams.begin();
+    while (it != unparsedParams.end())
     {
       Parameter* pp = 0;
       try
@@ -199,7 +199,7 @@ void AbstractParameterAliasable::aliasParameters(map<string, string>& unparsedPa
       aliasParameters(it->second, it->first);
       if (verbose)
         ApplicationTools::displayResult("Parameter alias found", it->first + " -> " + it->second + " = " + TextTools::toString(pp->getValue()));
-      unparsedParams.erase(it);
+      it = unparsedParams.erase(it);
     }
 
     if (unparsedParams.size() == unp_s)
