@@ -100,7 +100,7 @@ namespace bpp
 
     void fireParameterChanged(const ParameterList & parameters);
   
-    double randC() const throw (Exception)
+    double randC() const
     {
       double x= RandomTools::randGamma(getParameterValue("alpha"),
                                        getParameterValue("beta"));
