@@ -126,6 +126,14 @@ namespace bpp
  */
 class AttributesTools
 {
+private:
+  /*
+   * vector of param names already seen, to avoid infinite recursion
+   *
+   */
+  
+  static std::vector<std::string> vParam_;
+  
 public:
   AttributesTools() {}
   virtual ~AttributesTools() {}
@@ -218,7 +226,7 @@ public:
                                char varCode = '$',
                                char varBeg = '(',
                                char varEnd = ')');
-
+   
   /**
    * @brief Global function that reads all parameters from command line and files,
    * and set the values in a map.
